@@ -205,11 +205,6 @@ convertAllYaml2RDataframesT20 <- function(sourceDir=".",targetDirMen=".",targetD
         teams <- as.character(unique(overs$team))
         #Create a unique file which is based on the opposing teams and the date of the match
 
-        # Take into account name change for IPL "Kings XI Punjab" to "Punjab Kings"
-        if(meta$team1 == "Kings XI Punjab")
-            meta$team1 = "Punjab Kings"
-        if(meta$team2 == "Kings XI Punjab")
-            meta$team2 = "Punjab Kings"
         filename <- paste(meta$team1,"-",meta$team2,"-",meta$date,".",
                           "RData",sep="")
 
